@@ -1,4 +1,4 @@
-use anchor_lang::prelude::*;
+use anchor_lang::{prelude::*, solana_program::pubkey::PUBKEY_BYTES};
 
 #[account]
 #[derive(Copy, Debug, Default)]
@@ -15,6 +15,10 @@ pub struct Electorate {
     pub proposal_threshold: u64,
 }
 
+impl Electorate {
+    pub const LEN: usize = 1 + PUBKEY_BYTES * 3 + 8;
+}
+
 #[account]
 #[derive(Copy, Debug, Default)]
 pub struct TokenRecord {
@@ -31,3 +35,7 @@ pub struct TokenRecord {
     /// TODO(michael): Docs
     pub unfinalized_votes: u64,
 }
+
+impl TokenRecord {
+    pub const LEN: usize = 1 + PUBKEY_BYTES * 3 + 8 + 8;
+}
